/*
 * Copyright (c) 2018 DuckDuckGo
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.duckduckgo.app.privacymonitor.ui

import android.arch.lifecycle.MutableLiveData
import android.arch.lifecycle.ViewModel
import com.duckduckgo.app.privacymonitor.PrivacyMonitor
import com.duckduckgo.app.privacymonitor.model.*
import com.duckduckgo.app.privacymonitor.store.PrivacySettingsStore

class ScorecardViewModel(private val settingsStore: PrivacySettingsStore) : ViewModel() {

    data class ViewState(
            val domain: String,
            val beforeGrade: PrivacyGrade,
            val afterGrade: PrivacyGrade,
            val httpsStatus: HttpsStatus,
            val trackerCount: Int,
            val majorNetworkCount: Int,
            val allTrackersBlocked: Boolean,
            val practices: TermsOfService.Practices,
            val privacyOn: Boolean,
            val showIsMemberOfMajorNetwork: Boolean,
            val showEnhancedGrade: Boolean
    )

    val viewState: MutableLiveData<ViewState> = MutableLiveData()
    private var monitor: PrivacyMonitor? = null

    init {
        resetViewState()
    }

    fun onPrivacyMonitorChanged(monitor: PrivacyMonitor?) {
        this.monitor = monitor
        if (monitor == null) {
            resetViewState()
        } else {
            updatePrivacyMonitor(monitor)
        }
    }

    private fun resetViewState() {
        viewState.value = ViewState(
                domain = "",
                beforeGrade = PrivacyGrade.UNKNOWN,
                afterGrade = PrivacyGrade.UNKNOWN,
                httpsStatus = HttpsStatus.SECURE,
                trackerCount = 0,
                majorNetworkCount = 0,
                allTrackersBlocked = true,
                practices = TermsOfService.Practices.UNKNOWN,
                privacyOn = settingsStore.privacyOn,
                showIsMemberOfMajorNetwork = false,
                showEnhancedGrade = false
        )
    }

    private fun updatePrivacyMonitor(monitor: PrivacyMonitor) {
        viewState.value = viewState.value?.copy(
                domain = monitor.uri?.host ?: "",
                beforeGrade = monitor.grade,
                afterGrade = monitor.improvedGrade,
                trackerCount = monitor.trackerCount,
                majorNetworkCount = monitor.majorNetworkCount,
                httpsStatus = monitor.https,
                allTrackersBlocked = monitor.allTrackersBlocked,
                practices = monitor.termsOfService.practices,
                showIsMemberOfMajorNetwork = monitor.memberNetwork?.isMajor ?: false,
                showEnhancedGrade = monitor.grade != monitor.improvedGrade
        )
    }
}